Module light

Module light 

Light components and systems for dynamic lighting

Structs

AmbientLight
Ambient lighting that affects all objects uniformly. Only one ambient light should be active at a time.
DirectionalLight
A directional light (like the sun) that affects all objects uniformly.
GpuDirectionalLight
GpuPointLight
Storage-buffer-friendly point light with explicit 16-byte alignment.
LightBuffer
LightUniform
PointLight
A point light that radiates from a position in all directions.

Constants

MAX_DIRECTIONAL_LIGHTS
MAX_POINT_LIGHTS