Oxide Core engine prelude
Re-exports
pub use crate::app::app;pub use crate::app::create_renderer;pub use crate::app::run_app;pub use crate::app::App;pub use crate::app::AppBuilder;pub use crate::app::AppRunner;pub use crate::app::AppStage;pub use crate::app::DefaultPlugins;pub use crate::app::InputPlugin;pub use crate::app::Plugin;pub use crate::app::PluginGroup;pub use crate::app::PostUpdate;pub use crate::app::PreUpdate;pub use crate::app::Render;pub use crate::app::RenderPlugin;pub use crate::app::TransformPlugin;pub use crate::app::Update;pub use crate::asset::load_gltf_async;pub use crate::asset::register_material_asset;pub use crate::asset::AssetServerResource;pub use crate::asset::GltfSceneAssets;pub use crate::asset::MaterialAssets;pub use crate::camera::camera_controller_system;pub use crate::camera::CameraBuffer;pub use crate::camera::CameraComponent;pub use crate::camera::CameraController;pub use crate::camera::CameraUniform;pub use crate::ecs::RendererResource;pub use crate::ecs::Time;pub use crate::ecs::WindowResource;pub use crate::event::window_event_to_engine;pub use crate::event::EngineEvent;pub use crate::light::AmbientLight;pub use crate::light::DirectionalLight;pub use crate::light::LightBuffer;pub use crate::light::LightUniform;pub use crate::light::PointLight;pub use crate::light::MAX_DIRECTIONAL_LIGHTS;pub use crate::light::MAX_POINT_LIGHTS;pub use crate::render::RenderFrame;pub use crate::scene::gltf_scene_spawn_system;pub use crate::scene::queue_gltf_scene_spawn;pub use crate::scene::request_gltf_scene_spawn;pub use crate::scene::spawn_gltf_scene_hierarchy;pub use crate::scene::take_spawned_scene_roots;pub use crate::scene::GltfMeshRef;pub use crate::scene::MeshRenderer;pub use crate::scene::PendingGltfSceneSpawns;pub use crate::scene::SpawnedGltfScenes;pub use crate::ui::handle_egui_event;pub use crate::ui::EguiManager;pub use crate::ui::EguiRender;pub use crate::watcher::AssetWatcher;pub use crate::window::Window;
Structs
- Adapter
- Handle to a physical graphics and/or compute device.
- Camera
- Children
- Command
Encoder - Encodes a series of GPU operations.
- Command
Queue - Commands
- Depth
Texture - Device
- Open connection to a graphics and/or compute device.
- Entity
- Fallback
Texture - A 1x1 white texture used as a fallback when no texture is provided.
- Global
Transform - Gltf
Node - Represents a node in the glTF hierarchy.
- Gltf
Scene - Result of loading a glTF file.
- Handle
- A typed handle to an asset.
- Handle
Allocator - A counter for generating unique handles.
- Keyboard
Input - Mat2
- A 2x2 column major matrix.
- Mat3
- A 3x3 column major matrix.
- Mat4
- A 4x4 column major matrix.
- Material
Descriptor - Material
Pipeline - Mesh
- Mesh3D
- Mesh
Cache - Resource that caches GPU meshes by handle.
- Mesh
Filter - Component that references a mesh and material for rendering.
- Mouse
Delta - Mouse
Input - Parent
- Quat
- A quaternion representing an orientation.
- Query
- Queue
- Handle to a command queue on a device.
- Render
Pass - In-progress recording of a render pass: a list of render commands in a
CommandEncoder. - Render
Pipeline - Handle to a rendering (graphics) pipeline.
- Renderer
- Res
- ResMut
- Sampler
Descriptor - Descriptor for creating a sampler.
- State
- Surface
State - System
- Texture
- A GPU texture with its view and sampler.
- Transform
- Transform
Component - Vec2
- A 2-dimensional vector.
- Vec3
- A 3-dimensional vector.
- Vec4
- A 4-dimensional vector.
- Vertex
- Simple vertex for basic demos (position + color)
- Vertex3D
- Full 3D vertex format with position, normal, and UV
- World
Enums
- Builtin
Shader - Button
State - Gltf
Error - KeyCode
- Code representing the location of a physical key
- Material
Error - Material
Type - Mouse
Button - Shader
Descriptor - Shader
Source - Shader
Source Error - Texture
Error - Texture
Format - Format in which a texture’s texels are stored in GPU memory.
Constants
Traits
Functions
- attach_
child - builtin_
shader_ source - create_
basic_ pipeline - create_
lit_ pipeline - create_
shader - create_
unlit_ pipeline - cube_
indices - cube_
vertices - detach_
child - get_
material_ bind_ group_ layout - Returns the cached material bind group layout, creating it if necessary.
- in_
state - load_
gltf - Loads a glTF file and extracts meshes.
- load_
material_ descriptor - load_
shader_ source - load_
shader_ source_ from_ path - load_
wgsl - mark_
subtree_ dirty - sphere_
indices - sphere_
vertices - transform_
propagate_ system - triangle_
vertices - vec2
- Creates a 2-dimensional vector.
- vec3
- Creates a 3-dimensional vector.
- vec4
- Creates a 4-dimensional vector.
Type Aliases
- Surface
Configuration - Describes a
Surface.