SystemParam

Trait SystemParam 

pub trait SystemParam: Sized {
    // Required method
    unsafe fn fetch(world: *mut World, commands: *mut CommandQueue) -> Self;
}

Required Methods

unsafe fn fetch(world: *mut World, commands: *mut CommandQueue) -> Self

Fetches this parameter from raw world and command-queue pointers.

Safety

world and commands must be valid pointers for the duration of the call and must originate from the currently executing schedule stage.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl SystemParam for Commands

Source

impl<Q> SystemParam for Query<Q>
where Q: 'static,

Source

impl<T> SystemParam for Res<T>
where T: 'static,

Source

impl<T> SystemParam for ResMut<T>
where T: 'static,